#!/bin/sh
# Bryant Hansen

ME="$(basename "$0")"
USAGE="$ME"
PACKAGE_NAME=logfile-uploader

DebugMessage() {
    local LOG_RECORD_HEADER="`date "+%Y%m%d_%H%M%S"` (${ME}):"
    echo "${LOG_RECORD_HEADER} $*" >&2
}

SCRIPTS_RUNNING=$(pidof -o %PPID -x "$ME")
if [[ -n "$SCRIPTS_RUNNING" ]]; then
    DebugMessage " *** Not starting backup script - other instances are already running"
    exit 0
fi

echo -n "${ME} version: " >&2
opkg list-installed | grep "$PACKAGE_NAME" 1>&2
DebugMessage "${ME}: beginning upload operation on $(date)" >&2

if ! verify_client.sh ; then
    # TODO: consider if we should just verify or if the install should also be done here
    install_client.sh | /bin/sh
    if ! verify_client.sh ; then
        DebugMessage "Failed to install client functionality (new account registration may be pending...)."
        DebugMessage "Exiting abnormally."
        exit 2
    fi
fi

make_backup_linktree.sh | /bin/sh

do_sync_backup.sh | /bin/sh

cleanup_backup_tree.sh | /bin/sh
