#!/bin/sh
#   Copyright (c) 2013 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of dSS11 WebSetup.
#
#   This file is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This file is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

export PATH=/usr/local/bin:/usr/bin:/bin:/usr/local/sbin:/usr/sbin:/sbin
export SHELL=/bin/sh

. /www/pages/cgi-bin/errlib.sh
. /www/pages/cgi-bin/util.sh
. /www/pages/cgi-bin/webservice.sh

DSS_CONFIG_D="/usr/share/dss/data/config.d/webservice.xml"

DSID=`mac2dsid -i eth0`
MAC=`ifconfig eth0 | grep 'HWaddr' | awk '{ print $5}'`

log "Webservice deactivation started."

log "Removing old RemoteConnectivity tokens..."
DSS_JSON_RESPONSE=$(curl -s -H "Authorization: $HTTP_AUTHORIZATION" -H "Cookie: $HTTP_COOKIE" "http://127.0.0.1:8088/json/property/query?query=%2Fsystem%2Fsecurity%2FapplicationTokens%2F*%2F*(token%2CapplicationName")
RETCODE=$?
if [[ $RETCODE -ne 0 ]]; then
    log "Error: could not send request to query tokens from dSS, aborting, curl returned [$RETCODE]"
    exit 1
fi

SUCCESS=$(echo "$DSS_JSON_RESPONSE" | jq -M -r .ok)
if [[ "$SUCCESS" != "true" ]]; then
    log "Error: could not query application tokens, dSS replied with failure"
    exit 1
fi

for tkn in $(echo "$DSS_JSON_RESPONSE" | jq  -M -r '.result.enabled[] | select(.applicationName == "RemoteConnectivity") | .token')
do
    curl -s -X POST -H "Content-Length: 0" "$WEBSERVICE_BASEURL/public/accessmanagement/v1_0/RemoteConnectivity/DeleteApplicationToken?macAddress=${MAC}&token=${tkn}" 2>&1 >/dev/null
    curl -s -H "Authorization: $HTTP_AUTHORIZATION" -H "Cookie: $HTTP_COOKIE" "http://127.0.0.1:8088/json/system/revokeToken?applicationToken=$tkn" 2>&1 >/dev/null
done

WEBSERVICE_RESPONSE=$(curl -s -X POST -H "Content-Length: 0" "$WEBSERVICE_BASEURL/internal/accessmanagement/v1_0/RemoteConnectivity/DeactivateRemoteConnectivity?dssid=${DSID}")
RETCODE=$?
if [[ $RETCODE -ne 0 ]]; then
    log "Error: could not send request to webservice, curl returned [$RETCODE]"
    curl -s -H "Authorization: $HTTP_AUTHORIZATION" -H "Cookie: $HTTP_COOKIE" "http://127.0.0.1:8088/json/event/raise?name=remote-connectivity-disabled&parameter=success%3Dfalse%3Bmode%3D$MODE%3Bcode%3D$ERR_WEB_SERVICE" 2>&1 >/dev/null
fi

SUCCESS=$(echo "$WEBSERVICE_RESPONSE" | jq -M -r .ReturnCode)
if [[ -z "$SUCCESS" ]] || [[ "$SUCCESS" != "0" ]]; then
    ERR_MSG=$(echo "$WEBSERVICE_RESPONSE" | jq -M -r .ReturnMessage)
    log "Error: webservice returned $SUCCESS and said: $ERR_MSG"
    curl -s -H "Authorization: $HTTP_AUTHORIZATION" -H "Cookie: $HTTP_COOKIE" "http://127.0.0.1:8088/json/event/raise?name=remote-connectivity-disabled&parameter=success%3Dfalse%3Bmode%3D$MODE%3Bcode%3D$ERR_WEB_SERVICE%3Bservicecode%3D$SUCCESS" 2>&1 >/dev/null
fi

# write config.d
cat > $DSS_CONFIG_D << EOL
<?xml version="1.0" encoding="utf-8"?>
<properties version="1">
  <property name="config">
    <property name="webservice-api/enabled" type="boolean">
      <value>false</value>
    </property>
  </property>
</properties>
EOL

DSS_JSON_RESPONSE=$(curl -s -H "Authorization: $HTTP_AUTHORIZATION" -H "Cookie: $HTTP_COOKIE" "http://127.0.0.1:8088/json/property/setBoolean?path=/config/webservice-api/enabled&value=false")
RETCODE=$?
if [[ $RETCODE -ne 0 ]]; then
    log "Error: could not set webservice api property on dSS, curl returned [$RETCODE]"
fi

SUCCESS=$(echo "$DSS_JSON_RESPONSE" | jq -M -r .ok)
if [[ "$SUCCESS" != "true" ]]; then
    log "Error: could not set webservice api property on dSS"
fi

DSS_JSON_RESPONSE=$(curl -s -H "Authorization: $HTTP_AUTHORIZATION" -H "Cookie: $HTTP_COOKIE" "http://127.0.0.1:8088/json/event/raise?name=remote-connectivity-disabled&parameter=success%3Dtrue%3Bcode%3D$ERR_OK")
RETCODE=$?
if [[ $RETCODE -ne 0 ]]; then
    log "Error: could raise event on dSS, curl returned [$RETCODE]"
fi

SUCCESS=$(echo "$DSS_JSON_RESPONSE" | jq -M -r .ok)
if [[ "$SUCCESS" != "true" ]]; then
    log "Error: could not notify dSS that webservice has been disabled"
fi

usleep 20000000

KITE_MSG=$(sh /www/pages/cgi-bin/pagekiteconfig.sh off)
RETCODE="$?"
if [[ $RETCODE -ne 0 ]]; then
    # actually not possible for this to happen
    log "Erorr disabling pagekite: $KITE_MSG"
fi

log "Webservice deactivation done."
